@@ -16,10 +16,6 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "panel-application.h"
 #include "panel-base-window.h"
 #include "panel-dbus-service.h"
@@ -300,6 +296,7 @@ panel_application_xfconf_window_bindings (PanelApplication *application,
     { "output-name", G_TYPE_STRING },
     { "position", G_TYPE_STRING },
     { "enable-struts", G_TYPE_BOOLEAN },
+    { "keep-below", G_TYPE_BOOLEAN },
     { NULL }
   };
   const PanelProperty global_properties[] = {
@@ -1570,7 +1567,7 @@ panel_application_new_window (PanelApplication *application,
   /* put the window in its own group */
   window_group = gtk_window_group_new ();
   gtk_window_group_add_window (window_group, GTK_WINDOW (window));
-  g_object_weak_ref (G_OBJECT (window), _panel_utils_weak_notify, window_group);
+  g_object_weak_ref (G_OBJECT (window), (GWeakNotify) G_CALLBACK (g_object_unref), window_group);
 
   /* add the window to internal list */
   application->windows = g_slist_append (application->windows, window);
@@ -1626,7 +1623,11 @@ panel_application_new_window (PanelApplication *application,
   if (new_window)
     panel_application_save (application, SAVE_PANEL_IDS);
 
-  gtk_widget_show (GTK_WIDGET (window));
+  /*
+   * Do not show the panel window here, this will trigger allocation and/or critical
+   * warnings if the output to which it is assigned is disconnected. It will be shown
+   * in panel_window_screen_layout_changed() if necessary.
+   */
 
   return PANEL_WINDOW (window);
 }
